function find_gbo_dir, infil, makedir=makedir
;
;+
;NAME:
;	find_dbo_dir
;PURPOSE:
;	For a given GBO file, determine the week number and directory
;	that it should go in.  Optionally create that directory.
;CALLING SEQUENCE:
;	dirs = find_gbo_dir(infil)
;	dirs = find_gbo_dir(infil, /makedir)
;INPUT:
;	infil	- A single file name (or a list of file names)
;OPTIONAL KEYWORD INPUT:
;	makedir	- If set, and the required directory does not exist,
;		  then create the directory.  It will use disk which
;		  has the last GBO directory.
;HISTORY:
;	Written 27-Jan-93 by M.Morrison
;-
;
n = n_elements(infil)
outdir = strarr(n)
;
gbo_dirs = gbo_paths(/gbo_only)
;
for i=0,n-1 do begin
    break_file, infil(i), dsk_log, dir, filnam, ext
    fid = strmid(filnam, 3, 6) + strmid(ext, 0, 5)
    dattim = fid2ex(fid)
    tim2orbit, dattim, wid=wid
    wid=wid(0)
    ;
    p = strpos(gbo_dirs, wid)
    ss = where(p ne -1)
    if (ss(0) ne -1) then begin		;found a match
	outdir(i) = gbo_dirs(ss(0))
    end else begin
	if (keyword_set(makedir)) then begin
	    break_file, gbo_dirs(n_elements(gbo_dirs)-2), dsk_log, dir, filnam, ext
	    dirbase = dir
	    dir0 = 'gbo' + wid + 'a'
	    cmd = 'cd ' + dirbase + ' ; mkdir ' + dir0 + ' ; chmod 777 ' + dir0
	    spawn, cmd, result

	    outdir(i) = concat_dir(dirbase, dir0)
	    gbo_dirs = gbo_paths()		;update the gbo_dirs variable
	end
    end
end
;
if (n eq 1) then outdir = outdir(0)	;turn it into scalar
;
return, outdir
end
