function get_gbo_pfi, index, input1, input2, mask=mask, head=head, qstop=qstop
;+
;NAME:
;	get_gbo_pfi
;PURPOSE:
;	Given a SXT PFI index and either the file name of a ground 
;	based image, or the ground based image itself, GET_GBO_PFI will 
;	extract the portion of the GBO image corresponding to the SXT PFI.  
;SAMPLE CALLING SEQUENCE:
;	gbo_img = get_gbo_pfi(index, gbo_fullimg, gbo_time)
;	gbo_img = get_gbo_pfi(index,'/yd5/gbo91_46a/gkm911116.1958')
;
;METHOD/LIMITATIONS:
;	DSK_LOCB is called to find the center of the sun, so the GBO image must
;	be a full disk image and have a well defined limb.
;INPUTS:
;	index	- The SXT PFI index
;	input1	- The GBO file name. In this case, the date and time are extracted
;		  from the file header so it must be the Yohkoh format for the file
;		  name.
;			or
;		  The actual GBO image. 
;	input2	- The GBO date/time (only needed if "input1" is the GBO image
;		  and not the file name).
;OPTIONAL KEYWORD INPUTS:
;	mask	- If set, then call GBO_MASK to "clean up" the GBO image
;		  of writing on the image.
;HISTORY:
;	Written 12-Jan-94 by M.Morrison using Alan McAllister's GBO_PFI
;	routine as the conceptual starting point.
;       21-Mar-94 (SLF) Doc Header
;	
;-
;
if (data_type(input1) eq 7) then begin	;string type
    img = rfits2(input1, head=head)
    break_file, input1, dsk_log, dir, filnam, ext
    tarr = fid2ex(strmid(filnam, 3, 6) + strmid(ext, 0, 5))
end else begin
    img = input1
    tarr = anytim2ex(input2)
end
;
if (keyword_set(mask)) then img = gbo_mask(img)
;
index0 = index(0)
rb0p = get_rb0p(index0)
radius = rb0p(0)        ;in arcsec
;
dsk_locb, img,  horzcnt=x0, vertcnt=y0, horzrad=rx, vertrad=ry
pix2 = (radius*2)/((rx+ry)/2)		;rx and ry are actually diameters
print, 'GET_GBO_PFI: GBO center is      ', x0, y0
print, 'GET_GBO_PFI: GBO pixel size is: ', pix2
corner2 = [-x0, -y0]
;
;--- corner1 = gt_corner(index0, /from_sc)
pix1 = gt_pix_size(index0)
corner1a = gt_corner(index0)			;need to translate the coordinates
hel1a = conv_p2h(corner1a, index0)		;to correct for solar rotation
ang1b = track_h2a(tarr, hel1a, index0)
corner1 = ang1b/pix1				;invert so it is relative to sun center
						;and convert back to pixels

shape = gt_shape(index0)
if (keyword_set(qstop)) then stop

out = coal_image(img, corner2, corner1, shape, mag=pix2/pix1)

return, out
end
