;+
; NAME:
;      	lastgbo
; PURPOSE:
;	reads the last gki image (NSO/KP He 10830 images)
;       reads the last gbh image (Big Bear H-alpha)
;       reads the last gkm image (NSO/KP magnetogram)
;       reads the last gnt image (Nobeyama radioheliograph)
; CATEGORY:
; CALLING SEQUENCE:
;
;  lastgbo,gkiimg,gbhimg,gkmimg,gntimggkitime=t1,gbhtime=t2,
;          gkmtime=t3,gnttime=t3
;
; OPTIONAL (KEYWORD) INPUT PARAMETERS:
;	gbotime is the start time of the image scan, fmt_tim style
; OUTPUTS:
;	img1 (477,477), img2 (640,481), img3 (477,477), img4 (512,512)
; COMMON BLOCKS:
; ROUTINES CALLED:
;	gbo_paths, file_list, rfits, rfits2, anytim
; MODIFICATION HISTORY:
;	DA, HSH, RAS written 13-Apr-94
;       SLF 13-Apr-94 use /NOSHELL keyword in gbo_path call (inhibit shell)
;	HSH 18-Apr-94 fixed end-of-week problem with finding GKI's
;       DA  26-apr-94 modified lastgki to include several ground based images
;       DA  23-May-94 modified to do better job cleaning up GNT image
;       DA  21-Jun-94 corrected for change to gkm header
;	BNH  1-Jul-94 revamped method of aquiring time stamps to be much 
;	              more robust
;	BNH  7-Jul-94 Added /scale to RFITS call to scale gki, gkm data 
;                     correctly consistently...I hope.
;       SLF 15-Sep-94 use rfits2 instead of rfits (allow compressed data)
;       SLF  8-oct-94 use gbo_mask instead of hardcoded gbh indices
;-
pro lastgbo, gkiimg,gbhimg,gkmimg,gntimg,$ 
            gkitime=gkitime, gbhtime=gbhtime, gkmtime=gkmtime,gnttime=gnttime

dirs = gbo_paths(/gbo_only,/noshell)
n_dirs = n_elements(dirs)
gkis = file_list(dirs(n_dirs-2:n_dirs-1),'gki'+'*')
gbhs = file_list(dirs(n_dirs-2:n_dirs-1),'gbh'+'*')
gkms = file_list(dirs(n_dirs-2:n_dirs-1),'gkm'+'*')
gnts = file_list(dirs(n_dirs-2:n_dirs-1),'gnt'+'*')

last1 = 0
last2 = 0
last3 = 0
last4 = 0
if n_elements(gkis) ne 0 then last1 = n_elements(gkis)-1
if n_elements(gbhs) ne 0 then last2 = n_elements(gbhs)-1
if n_elements(gkms) ne 0 then last3 = n_elements(gkms)-1
if n_elements(gnts) ne 0 then last4 = n_elements(gnts)-1

gkiimg = rfits2(gkis(last1),head=head1, /scale)
gbhimg = rfits2(gbhs(last2), date=gbhdate, time=gbhtime)
gkmimg = rfits2(gkms(last3),head=head3, /scale)
gntimg = rfits2(gnts(last4),head=head4)

;
;  Scale Nobeyama to remove background and to limit
;  effects of very bright pixels
;
gntimg=gntcleen(gntimg)
;
;  Remove headers and date from image
gbhim=gbo_mask(gbhimg)
;================================================== GKI DATE
ic = wc_where(strupcase(head1),'DATE*')
gkitime = str_replace(strmid(head1(ic),(strpos(head1(ic),"'"))(0)+1,8), $
          '-','/') 
ic = (wc_where(strupcase(head1),'*TIME*'))(0)
gkitime = gkitime + ' ' + strmid(head1(ic),(strpos(head1(ic),"'"))(0)+1,8)
gkitime = fmt_tim(gkitime)
;================================================== GBH DATE
gbhtime = fmt_tim(gbhdate+ ' ' + gbhtime)
;================================================== GKM DATE
ic = wc_where(strupcase(head3),'DATE*')
gkmtime = str_replace(strmid(head3(ic),(strpos(head3(ic),"'"))(0)+1,8), $
          '-','/')
ic = (wc_where(strupcase(head3),'*TIME*'))(0)
gkmtime = gkmtime + ' ' + strmid(head3(ic),(strpos(head3(ic),"'"))(0)+1,8)
gkmtime = fmt_tim(gkmtime)
;================================================== GNT DATE
ic = wc_where(strupcase(head4),'DATE*')
gnttime = str_replace(strmid(head4(ic),(strpos(head4(ic),"'"))(0)+1,8), $
          '-','/')
ic = (wc_where(strupcase(head4),'*TIME*'))(0)
gnttime = gnttime + ' ' + strmid(head4(ic),(strpos(head4(ic),"'"))(0)+1,8)
gnttime = fmt_tim(gnttime)
;================================================== 

end
