pro mk_gev, week=week, outdir=outdir, run_time=run_time
;
;+
;NAME:
;	mk_gev
;PURPOSE:
;	Take the daily text GOES event summary file and make a 
;	weekly binary log file
;KEYWORD INPUT:
;       week    - a string with the year/week if the format
;                 91_49 where 91 is the year, 49 is the week
;                 This is required input.
;OPTIONAL KEYWORD INPUT:
;	outdir	- The output directory for the output file.
;		  If undefined, write it to $DIR_GEN_GEV.
;HISTORY:
;	Written 4-Jun-92 by M.Morrison
;	28-Aug-92 (MDM) - Modified how RD_FEM was called (call by week#)
;       14-May-93 (MDM) - Changed to use $ydb_raw and $ys
;	18-May-93 (MDM) - Minor patch in checking that there is data
;        2-dec-96 (SLF) - SEL format change - use rd_selsis2 for new data
;-
;
start_time = systime(1)
run_time = 0.
;
qdebug = 1
;
progVerNo = 1.00*1000
progName = 'MK_GEV.PRO'
;
if (n_elements(outdir) eq 0) then outdir = '$DIR_GEN_GEV'
;
weekid = string(week, fix(progverno/1000), format="(a, 'a.', i2.2)")
outfil       = concat_dir('$DIR_REFORMAT_SC', 'gev'+weekid)
outfil_final = concat_dir(outdir, 'gev'+weekid)
indir = '$ydb_raw/selsis_events/'
;
yearn = fix(strmid(week, 0, 2))
weekn = fix(strmid(week, 3, 2))
rd_fem, weekn, yearn, fem_data
ss = where((fem_data.week eq weekn) and (fem_data.day_rev eq 1))
days = strlowcase(gt_day(fem_data(ss), /str, /leadzero))
days = str_replace(days, '-', '')
infil = indir + days + '_events.text'

if week gt '96_38' then begin
   pr_week2tim,week,d0,d1
   days=timegrid(d0,d1,/day,/string)
   fids=strmid(ex2fid(anytim2ex(days)),0,6)
   infil=file_list(indir,'*'+fids+'events.txt')
   rd_selsis2, infil, goes
endif else rd_selsis, infil, goes

if (get_nbytes(goes) lt 5) then return		;no data files available
;
lunout = 2      ;output log
gen_struct, file_header=fhead
;
rsiz = 16
open_da_file, lunout, '', '', outfil, rsiz, bytout, fpoint, /nolower
;
rdwrt, 'W', lunout, bytout, rsiz, goes, 1
;
;-------------------- Write out pointer and file header

ndatasets = n_elements(goes)
maxsamps = get_nbytes(goes(0))
totbytes = bytout

fpoint.TotBytes         = totbytes

fhead.nDataSets         = nDataSets
fhead.maxSamps          = maxSamps

gbo_struct, gbo_version=gbo_version
fpoint.data_version     = gbo_version.gev
file_id = weekid
wrt1p_fh, lunout, fpoint, fhead, rsiz, progName, progVerNo, file_id, 'GEV', 'GEV'
;
close, lunout
;
if (n_elements(outfil_final) ne 0) then begin
    cmd = 'rm -f ' + outfil_final               ;remove any copy of the file that might already exist
    spawn, cmd
    cmd = 'mv ' + outfil + ' ' + outfil_final
    spawn, cmd
end

end_time = systime(1)
run_time = (end_time-start_time)/60.
;
end
