pro mk_gsn_obs_s1, lun, tape_name, eot, itapefile, neof, obs, obshdr, $
	qstop=qstop, qdb=qdb, q2db2=q2db, save_header=save_header, $
	save_img=save_img, archive_fulldisk=archive_fulldisk
;
;+
;NAME:
;	mk_gsn_obs_s1
;PURPOSE:
;	To build the SOON/SPOT observing log entries for a single tape file
;	and the pointer/summary structure for that file
;INPUT:
;	lun	- the logical unit of the opened tape drive
;	tape_name- the tape name
;INPUT/OUTPUT:
;	eot	- end of tape marker
;	itapefile-the file number on the tape
;	neof	- the number of consecutive end of file marks found
;OUTPUT:
;	obs	- the observing log entry array for that one tape file
;	obshdr	- the pointer/summary structure for that tape file
;OPTIONAL KEYWORD INPUT:
;	qstop	- If set, then stop within the program (for debugging)
;	save_head - If set, save the first "save_head" headers for each
;		  file on the tape
;	save_img - If set, then save the first "save_img" images for each
;		  file on the tape
;	archive_fulldisk - If set, then save the first full disk image in
;		  each tape file to $DIR_GBO_SOON
;HISTORY:
;	Written Dec-93 by M.Morrison
;	(See MK_GSN_OBS.PRO for a history)
;	22-Sep-94 (MDM) - Added print statement of REF_TIME
;-

if n_elements(q2db) eq 0 then q2db = 0
eot = 0
start_time = systime(1)
qstop = keyword_set(qstop)
;
obshdr = {gsn_pointer_rec}
;
h = bytarr(2880*2)
;
avg_xpix_siz = 0.
avg_ypix_siz = 0.
;
ref_time = !stime
if (tape_name ne '') then ref_time = anytim2ints( fid2ex(strmid(tape_name, 3, 6)+'.0000') )
print, 'REF_TIME = ' + fmt_tim(ref_time)
;
tape_name0 = ''
iimg = 0
qdone = 0
while (not qdone) do begin
    on_ioerror, io_prob
    if (iimg eq 0) then readu, lun, h $
		   else readu, lun, h, img, pad
    on_ioerror, null

    h_str = string(reform(h,80,72))
    iimg = iimg + 1
    neof = 0		;reset the number of consecutive EOF counter

    if (iimg eq 1) then begin				;first image in the tape file
	nout	= fxpar(h_str,'FILE-LEN')
	nx	= fxpar(h_str,'NAXIS1')
	ny	= fxpar(h_str,'NAXIS2')
	img = bytarr(nx, ny)
	pad = bytarr(2880 - (nx*ny mod 2880))
	readu, lun, img, pad

	obs = replicate({gsn_obs_rec}, nout)
    end

    timstr	= strtrim(fxpar(h_str,'TIME-OBS'),2)
    datstr	= strtrim(fxpar(h_str,'DATE-OBS'),2)
    tim = anytim2ints(datstr + ' ' + timstr)
    qtim_ok = (abs(int2secarr(tim, ref_time)) lt 30*86400.)    ;check day/time is not corrupted (needs to be within 30 days)
    if (not qtim_ok) then begin	
	tim.day = 0
	tim.time = 0
    end

    xpix_siz	= fxpar(h_str,'CDELT1')
    ypix_siz	= fxpar(h_str,'CDELT2')
    object0	= strtrim(fxpar(h_str,'OBJECT'),2)
    trans	= fxpar(h_str,'TRANS')
    pa		= fxpar(h_str,'PA')
    rv		= fxpar(h_str,'RV')
    xpix_ref	= fxpar(h_str,'CRPIX1')
    ypix_ref	= fxpar(h_str,'CRPIX2')
    lat		= fxpar(h_str,'LAT')
    lon		= fxpar(h_str,'LON')
    ;
    avg_xpix_siz = avg_xpix_siz + xpix_siz
    avg_ypix_siz = avg_ypix_siz + ypix_siz

    gsn_info, h_str, tim, site, image_type, tape_name
    ;
    if (iimg eq 1) then begin
	object = object0
    end else begin
	if (strmid(object0, 0, 2) ne 'SN') then object=object0	;only update if not SN number
    end
    ;
    if (qtim_ok) then rb0p = get_rb0p(tim) else rb0p = get_rb0p(ref_time)
    r = rb0p(0)		;the radius of the sun in arcseconds
    p = rb0p(2)		;the P-angle in radians
    ;
    xshift = (xpix_ref-nx/2)*xpix_siz		;shift from ref pixel to center in arcseconds
    yshift = (ypix_ref-ny/2)*ypix_siz
    location = intarr(2)
    location(0) = (cos(pa*!pi/180+!pi/2-p)*rv*r - xshift) * 10	 ;convert to 0.1 arcsec units (0 is straight up)
    location(1) = (sin(pa*!pi/180+!pi/2-p)*rv*r - yshift) * 10
    if (iimg eq 1) then avg_location = float(location) else $
	avg_location = avg_location + float(location)

    location_ref = intarr(2)
    location_ref(0) = (cos(pa*!pi/180+!pi/2-p)*rv*r)	;in arcseconds
    location_ref(1) = (sin(pa*!pi/180+!pi/2-p)*rv*r)
    location_fits = conv_h2a( [lon, lat], ref_time )
    del_location = sqrt(total( (location_ref-location_fits)^2) )
    qloc_ok = (del_location lt 60.0)	
	; derived location is within 1 arcminute of FITS LAT/LON
    if (strmid(object0,0,4) eq '9999') then qloc_ok = 1	;full disk image
    print, object, '  del_location: ', del_location
    print, '   Predicted: ' + conv_a2h(location_ref, tim, /str) + $
	   '   FITS: ' + conv_h2hs([lon,lat])
    print, '   PIXEL SIZE: ' + $
	   '     X Pixel Size: ' + string(xpix_siz) + $
	   '     Y Pixel Size: ' + string(ypix_siz)

    qpixsiz_ok = (((abs(xpix_siz) ge 3.0) and (abs(ypix_siz) ge 3.0) and (strmid(object0,0,4) eq '9999')) or $
		  ((abs(xpix_siz) lt 3.0) and (abs(ypix_siz) lt 3.0) and (strmid(object0,0,4) ne '9999')))

    obs(iimg-1).time		= tim.time
    obs(iimg-1).day		= tim.day
    obs(iimg-1).image_type	= image_type(0)
    obs(iimg-1).tranpar		= byte((trans*25)<255)
    obs(iimg-1).location	= location
    obs(iimg-1).image_num	= iimg
    obs(iimg-1).image_avg	= total(img)/nx/ny*100		;*100 to give some resolution
    ;
    if (iimg eq 1) then begin
	location0 = float(location)
	loc_dev = 0
    end else begin
	dev = sqrt(total( (location-location0)^2) )
	loc_dev = max([dev, loc_dev])
    end
    ;
    if (keyword_set(qdb)) then print, 'Image ' + string(iimg)+ ' of ', nout, $
				' for file  ' + string(itapefile) + '  ' + datstr + ' ' + timstr
    ;
    ;if (tape_name0 eq '') and (abs(int2secarr(tim, ref_time)) lt 30*86400.) then begin
    if (tape_name0 eq '') then begin
	prefix = 'st' + strlowcase( site )
	fid = strmid(ex2fid( anytim2ex( obs(iimg-1) ) ), 0, 6)    ;940625
	tape_name0 = prefix + fid
	message = ['PREDICTED TAPE NAME: ' + tape_name0, $
			'INPUT TAPE NAME:     ' + tape_name]
	prstr, message  + ' <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< '
	if (tape_name eq '') then tape_name = tape_name0	;use best guess tape name
	if (tape_name ne tape_name0) and (itapefile eq 1) then begin
	    message = ['MK_GSN_OBS Tape name mis-match WARNING', ' ', 'Re-run with proper name?', message]
	    mail, message, /self
	end
    end

    if (keyword_set(save_header)) then if (iimg le save_header) then begin
	outfil = string('head_' +tape_name, itapefile, iimg, format='(a, ".", i3.3, "_", i4.4)')
	prstr, h_str, file=outfil
    end
    if (keyword_set(save_img)) then if (iimg le save_img) then begin
	outfil = string('img_'+tape_name, itapefile, iimg, format='(a, ".", i3.3, "_", i4.4)')
	wrt_fits, outfil, h_str, img
    end
    if (keyword_set(archive_fulldisk) and (iimg eq 1) and qtim_ok and (strmid(object,0,4) eq '9999')) then begin
	outfil = 'g' + strlowcase( site ) + strlowcase( image_type ) + ex2fid( anytim2ex(tim) )
	outfil = concat_dir(getenv('DIR_GBO_SOON'), outfil)
	check_outfil = strmid(outfil, 0, strlen(outfil)-4)	;drop of time portion
	fff = findfile(check_outfil + '*')
	print, 'Checking for the existence of: ', check_outfil
	if (fff(0) eq '') then begin
	    if (file_exist(outfil)) then file_delete, outfil
	    wrt_fits, outfil, h_str, img	;no files for that day
	end else begin
	    print, 'File(s) already exist for that day.  Not saving this image'
	    prstr, '   ' + fff
	end
    end
    ;
    if (keyword_set(q2db) and ((not qtim_ok) or (not qloc_ok) or (not qpixsiz_ok))) then begin
	out = ['TAPE_NAME: ' + tape_name, $
			string(itapefile, iimg, format='("TAPE_FILE: ", i3.3, "  IMAGE: ", i4.4)'), $
			'------------------------------------------------------------------------------']
	if (not qtim_ok) then out = [out, 'BAD TIME: ' + datstr + ' ' + timstr]
	if (not qloc_ok) then out = [out, 'BAD LOCATION: ', $
  		'     Heliocentric derived from PA/RV: ' + $
			conv_a2h(location_ref, tim, /str), $
		'     Heliocentric from FITS header:   ' + $
			conv_h2hs([lon,lat])]
	if (not qpixsiz_ok) then out = [out, 'PIXEL SIZE INCOMPATIBLE WITH OBJECT ID: ', $
					     '     OBJECT ID: ' + strmid(object0,0,4) + $
					     '     X Pixel Size: ' + string(xpix_siz) + $
					     '     Y Pixel Size: ' + string(ypix_siz)]
	out = [out, '------------------------------------------------------------------------------']
	outfil = string('badhead_' +tape_name, itapefile, iimg, format='(a, ".", i3.3, "_", i4.4)')
	outfil = concat_dir(getenv('DIR_GSN_BADHEAD'), outfil)
	if (file_exist(outfil)) then file_delete, outfil
	out = [out, h_str]
	prstr, out, file=outfil
    end

    if (qstop) then stop
    goto, skip
    io_prob:
	qdone = 1
	if (keyword_set(qdb)) then print, !err_string
	;
	obshdr.n_images = iimg
	if (iimg ne 0) then begin
	    obs2 = obs
	    sss = where(obs2.day ne 0)
	    if (sss(0) ne -1) then obs2 = obs2(sss)		;get rid of the bad times
	    ;
	    image_types = [obs2.image_type]
	    if (n_elements(image_types) gt 1) then image_types = image_types(uniq(image_types, sort(image_types)))
            x = int2secarr(obs2)
	    
	    dummy = min(x, imin)
	    obshdr.time		= obs2(imin).time
	    obshdr.day		= obs2(imin).day
	    obshdr.duration	= max(x)-min(x)

	    obshdr.st$tape_name = byte(tape_name)
	    obshdr.file_num	= itapefile

	    obshdr.site		= site(0)
	    obshdr.st$object	= byte(object)
	    obshdr.image_types	= image_types

	    obshdr.image_shape	= [nx,ny]
	    obshdr.pix_siz	= [avg_xpix_siz/iimg*1000., avg_ypix_siz/iimg*1000.]
	    obshdr.location	= fix(avg_location/iimg)
	    obshdr.location_del	= loc_dev < 32000.

	    itapefile = itapefile + 1
	end
	;
	iimg = 0
	neof = neof + 1
	if (neof gt 5) then begin	;got to the end of the tape - expect 2-3 eof between files
	    eot = 1
	    return
	end
    skip:
end
;
end_time = systime(1)
run_time = (end_time - start_time)/60.		;minutes
if (keyword_set(qdb)) then print, 'It took: ', run_time, ' minutes to read one tape file'
end
