
function read_eye,filnam,date=date0,time=time0,header=header

;+
; NAME:
;        READ_EYE
; PURPOSE:
;        Reads BBSO Quantex, Datacube, and Eyecom files.
; CATEGORY:
;        Input/Output.
; CALLING SEQUENCE:
;        result = read_eye(filename)
; INPUTS:
;        filename = string containing the file name.
; OUTPUTS:
;        result = byte, integer, or long array, containing the FITS data
;	   array.  The dimensionality of result reflects the structure
;	   of the FITS data.
; OPTIONAL (KEYWORD) OUTPUT PARAMETERS:
;        date = date of observation (string).
;        time = time of observation (string).
;        header = string containing the full FITS header (80 characters
;	   per FITS keyword parameter).
; RESTRICTIONS:
;        Only works on simple BBSO FITS files.  FITS extensions
;	   (e.g., groups and tables) are not supported.
; MODIFICATION HISTORY:
;        Version 1.0 - GLS, Dec, 1990.
;-

SET_PLOT,'X'	; DEBUG
row_len = [512,640,640]
type_string = 'EYDAFT'

filetype = $
  strpos(type_string,strupcase(strmid(filnam, $
    strpos(filnam,'.',strlen(filnam)-4)+1,2)))
if filetype ne -1 then filetype = filetype/2
if (filetype eq 2) then b_len = 2880l else b_len = 512l
get_lun,unit & openr,unit,filnam & a = assoc(unit,bytarr(b_len,/nozero))
header = '' & n_hblock = 0 & end_pos = -1
while end_pos eq -1 do begin
  buff = a(n_hblock)
  header = header+string(buff)
  end_pos = strpos(strupcase(header),'END')
  n_hblock=n_hblock+1

PRINT,N_HBLOCK

endwhile
nh = end_pos / 80 & rem_len = end_pos mod 80
if (filetype gt 0) and ((b_len - (end_pos mod b_len)) lt 80) then $
  n_hblock=n_hblock+1

; Find BITPIX keyword in header (bits per pixel, should always be 8):
h_start = strpos(strupcase(header),'BITPIX',0)
if h_start ne -1 then begin
  bitpix = fix(strmid(header,h_start+10,21))
endif else begin
  bitpix = 8
  print,' Keyword BITPIX not found in header.'
  print,' BITPIX assumed to be 8 bits per pixel.'
endelse  

; Find NAXIS keyword in header (number of dimensions of image data):
h_start = strpos(strupcase(header),'NAXIS ',0)
if h_start ne -1 then begin
  naxis = fix(strmid(header,h_start+10,21))
endif else begin
  naxis = 2
  print,' Keyword NAXIS not found in header.'
  print,' NAXIS assumed to be 2.'
endelse  

; Find NAXISi keywords in header (pixels per row):
axis_len = lonarr(naxis)
for i=0,naxis-1 do begin
  sea_str = 'NAXIS'+string(i+1,format='(i1)')
  h_start = strpos(strupcase(header),sea_str,0)
  if h_start ne -1 then begin
    axis_len(i) = fix(strmid(header,h_start+10,21))
  endif else begin
    case i of
      0: axis_len(i) = row_len(filetype)
      1: axis_len(i) = 481
      else: axis_len(i) = 1
    endcase
    print,' Keyword ' + sea_str + ' not found in header.'
    print,' ' + sea_str + ' assumed to be ' + $
	  string(axis_len(i),format='(i3)') + '.'
  endelse
endfor

; Find DATE-OBS keyword
h_start = strpos(strupcase(header),'DATE-OBS',0)
if h_start ne -1 then begin
  date0 = strtrim(strmid(header,h_start+10,21),2)
endif else begin
  date0 = ' 0/ 0/ 0'
  print,' Keyword DATE-OBS not found in header.'
  print,' DATE set to 0/ 0/ 0.'
endelse  

; Find TIME-OBS keyword
h_start = strpos(strupcase(header),'TIME-OBS',0)
if h_start ne -1 then begin
  time0 = strtrim(strmid(header,h_start+10,21),2)
endif else begin
  time0 = ' 0: 0: 0'
  print,' Keyword TIME-OBS not found in header.'
  print,' TIME set to 0: 0: 0.'
endelse  

; Get image
length = axis_len(0)*axis_len(1)
n_dblock = length / b_len
if n_dblock mod b_len ne 0 then n_dblock=n_dblock+1
close,unit & openr,unit,filnam
dum1 = bytarr(b_len*n_hblock,/nozero)
image = bytarr(b_len*n_dblock,/nozero)
readu,unit,dum1 & readu,unit,image
image = image(0:length-1)
image = reform(image,axis_len(0),axis_len(1))
if (filetype eq 1) then image = rotate(image,7)
if (filetype eq 0) then image = image(48:559,0:478)

free_lun,unit
return,image
end

