pro selsisi2fits, infil, outdir, delete=delete, auto_dir=auto_dir
;
;+
;NAME:
;	selsisi2fits
;PURPOSE:
;	Take a SELSIS file and write a FITS file output
;INPUT:
;	infil	- a list of files in SELSIS format
;OPTIONAL KEYWORD INPUT:
;	delete	- if set, delete the SELSIS format file after
;		  the FITS file is created
;	auto_dir- if set, call FIND_GBO_DIR to figure out which
;		  output directory to use
;HISTORY:
;	Written 16-Jul-92 by M.Morrison
;	13-Oct-92 (MDM) - Modified to check if the call to "rd_selsisi"
;			  was successful.
;	27-Jan-93 (MDM) - Added /AUTO_DIR option, and using FIND_GBO_DIR
;			- Also change protection to 666
;       19-Aug-93 (MDM) - Removed /self switch from Mail call
;	 3-Jan-93 (MDM) - Removed mail message on "non-copies"
;-
;
if (n_elements(infil) eq 0) then return	;
if (infil(0) eq '') then return		;findfile found nothing
if (n_elements(outdir) eq 0) then outdir = ''
;
for i=0,n_elements(infil)-1 do begin
    print, 'Now Processing ', infil(i)
    img = rd_selsisi(infil(i), fits=fits, outfil=outfil, qerror=qerror)
    if (not qerror) then begin
	if (keyword_set(auto_dir)) then outdir = find_gbo_dir(outfil, /makedir)
	full_outfil = concat_dir(outdir, outfil)
	if (file_exist(full_outfil)) then begin
	    message = ['SELSISI2FITS.  File exists: ', infil(i), 'The file will not be copied']
	    print, message
	    ;;mail, message, subj='SELSISI2FITS message', user='morrison'
	end else begin
	    wrt_fits, concat_dir(outdir, outfil), fits, img
	    spawn, 'chmod 666 ' + concat_dir(outdir, outfil)
	end
	qdelete = keyword_set(delete)
    end else begin
	message = ['SELSISI2FITS had a problem with file: ', infil(i), 'The file will be deleted']
	;;mail, message, subj='SELSISI2FITS message', user='morrison'
	qdelete = 1		;always delete the bad files
    end
    ;
    if (qdelete) then begin
	cmd = 'rm -f ' + infil(i)
	spawn, cmd
    end
end
;
end
