;+
;NAME:
;	soon_sea
;PURPOSE:
;	TO allow access to the SOON catalog
;CALLING SEQUENCE:
;	.run soon_sea
;HISTORY:
;	Written 5-Aug-94 by M.Morrison
;	23-Sep-94 (MDM) - Changed start/stop time format statement
;			- Change "LI" option to allow user to select
;			  which tape files to list
;			- Added "SI" option to do per image listing of
;			  search results.
;	19-Apr-95 (MDM) - Adjusted to work to search for full disk
;			  images without specifying a region
;			- Corrected some catalog selection problems
;			  (it wasn't parsing the times properly)
;	25-Apr-95 (MDM) - Corrected error where full disk searches
;			  were not being reset.
;-
;
dir = getenv('DIR_GSN_OBS')
prefix = 'st*'
;
if (n_elements(sttim) eq 0) then sttim = ' 1-MAY-94'
if (n_elements(entim) eq 0) then entim = gt_day(!stime, /str)
if (n_elements(catfiles) eq 0) then catfiles = ''
if (n_elements(mail_address) eq 0) then mail_address = 'NONE'
if (n_elements(qmail) eq 0) then qmail = 0
if (n_elements(sea_info) eq 0) then sea_info = 'NO search location specified'
catfiles = file_seltime(dir, prefix, sttim, entim, /last_before)
;
en_dis_arr = ['Disabled', 'Enabled']
code = ' '
code2 = ' '
qdone = 0
while not qdone do begin
	print, '--------- Current settings are: ------------
	print, '   Starting/End date/time for search: '+ sttim + ' / ' + entim
	print, '   Search Info:           ' + sea_info
	print, '   Mail listing results:  ' + en_dis_arr(qmail) + '  (Address: ' + mail_address + ')'
	print, ' '
	print, 'Enter "ST" to change the starting time'
	print, '      "ET" to change the ending time'
	print, '      "LF" to list the SOON catalog files selected'
	print, '      "LS" to display a summary listing for selected catalog files
	print, '      "LI" to display an image listing for a catalog file
	print, '      "PL" to plot FOV locations for a catalog file
	print, '      "SR" to specify the solar region to search for
	print, '      "SS" to start the search
	print, '      "SP" to plot FOV locations for the search results
	print, '      "SL" to display a summary listing for the search results
	print, '      "SI" to display an image listing for the search results
	print, '      "MA" to set the mailing address
	print, '      "ME" to enable mailing results to address
	print, '      "MD" to disable mailing results to mail address
	print, '      "X" to exit this program
	read, 'Enter your option: ', code
	;
	outfil = ''
	if (qmail) and (mail_address ne 'NONE') then outfil = concat_dir(getenv('HOME'), 'soon_sea.temp')
	;
	case strupcase(code) of
	    ;--------------------- Specifications of start/end times
	    'ST': begin
			input, 'Enter start date/time', sttim, sttim
			sttim = fmt_tim(sttim)			;gt_day(sttim, /str)
			catfiles = file_seltime(dir, prefix, sttim, entim, /last_before)
		 end
	    'ET': begin
			input, 'Enter ending date/time', entim, entim
			entim = fmt_tim(entim)			;gt_day(entim, /str)
			catfiles = file_seltime(dir, prefix, sttim, entim, /last_before)
		 end

	    ;--------------------- Searching options
	    'SR': begin
			print, 'Enter C to specify latitude and carrington longitude
			print, '      H to specify heliocentric coordinate
			print, '      F to specify full disk images
			read, 'Enter your option: ', code2
			carrington = 0
			helio = 0
			full_disk = 0
			case strupcase(code2) of
			  'C': begin
				carrington = 1
				read, 'Enter the latitude, carrington longitude', lat, lon
				ref_loc = [lon, lat]
				sea_info = 'Search on Carrington Lat/Lon: ' + arr2str(ref_loc)
			       end
			  'H': begin
				helio = 1
				input, 'Enter the heliocentric coord (ie: N12W12)', ref_loc, 'N12W12'
				input, 'Enter the date that accompanies that coordinate', ref_date, '9-Jul-94'
				sea_info = 'Search on Heliocentric Coordinate: ' + ref_loc + ' for ' + ref_date
			       end
			  'F': begin
				full_disk = 1
				ref_loc = 'FULLD'
				sea_info = 'Search for full disk images'
			       end
			endcase
		 end
	    'SS': begin
			if (n_elements(ref_loc) eq 0) then begin
			    print, 'Please specify the search location using option "SR" '
			    tbeep, 3
			end else begin
			    sea_head = 0b
			    qfirst = 1
			    if (catfiles(0) ne '') then for ifil=0,n_elements(catfiles)-1 do begin
				print, 'Searching ' + catfiles(ifil)
				rd_gsn, catfiles(ifil), head		;, obs, imap
				entim_arr = anytim2ints(head, off=head.duration)
				qok = in_fov(ref_loc, ref_date, gsn=head, carrington = carrington, $
						helio=helio, full_disk=full_disk, /boolean)
				obj = string(head.st$object)
				if (keyword_set(full_disk)) then begin
				    ss = where(qok and (tim2match(sttim, head, entim_ref=entim, /entim_dur) ge 0))
				end else begin
				    ss = where(qok and (strmid(obj, 0, 4) ne '9999') and $
						(tim2match(sttim, head, entim_ref=entim, /entim_dur) ge 0))
				end
				if (ss(0) ne -1) then begin
				    if (qfirst) then sea_head = head(ss) else sea_head = [sea_head, head(ss)]
				    qfirst = 0
				end
			    end
			    sea_tit = ['SOON/SPOT  ' + sea_info, $
					'Time range Searched: ' + sttim + ' to ' + entim]
			end
		 end
	    'SP': begin
			if (data_type(sea_head) ne 8) then begin
			    print, 'No Search Results to Display' 
			    tbeep, 3
			end else begin
			    plot_gsn, gsn_head=sea_head, tit=arr2str(sea_tit, delim='!c')
			end
		  end
	    'SL': begin
			if (data_type(sea_head) ne 8) then begin
			    print, 'No Search Results to List'
			end else begin
			    pr_gsn, /sum, gsn_head=sea_head, outfil=outfil, comment=sea_tit
			    if (keyword_set(outfil)) then mail, file=outfil, user=mail_address, subj='SOON_SEA'
			end
		  end
	    'SI': begin
			if (data_type(sea_head) ne 8) then begin
			    print, 'No Search Results to List'
			end else begin
			    pr_gsn, catfiles, summary_arr, /sum, gsn_head=sea_head
			    pr_gsn, catfiles, outfil=outfil, comment=sea_tit, tapefile=summary_arr
			    if (keyword_set(outfil)) then mail, file=outfil, user=mail_address, subj='SOON_SEA'
			end
		  end
	    ;--------------------- Listing options
	    'LF': begin
			if (catfiles(0) eq '') then print, 'No files selected right now' $
					else prstr, catfiles
		 end
	    'LS': begin
			;;imenu = wmenu_sel(catfiles, /one)
			;;if (imenu ne -1) then pr_gsn, catfiles(imenu), /sum, outfil=outfil
			pr_gsn, catfiles, /sum, outfil=outfil
			if (keyword_set(outfil)) then mail, file=outfil, user=mail_address, subj='SOON_SEA'
		  end
	    'LI': begin
			print, 'Stand by - making a summary listing of the file on the tapes
			pr_gsn, catfiles, summary_arr, /sum
			print, 'Please select the tape files for which you want image listings'
			imenu = wmenu_sel(summary_arr)
			if (imenu(0) ne -1) then begin
			    print, 'Per image listing of the following tape files:'
			    prstr, summary_arr(imenu)
			    print, '   '
			    print, '   '
			    pr_gsn, catfiles, outfil=outfil, tapefile=summary_arr(imenu)
			    if (keyword_set(outfil)) then mail, file=outfil, user=mail_address, subj='SOON_SEA'
			end
		  end
	    ;--------------------- Plotting options
	    'PL': begin
			yesnox, 'Plot location for all files (other option is to select one file)', ans, 'Yes'
			if (ans) then begin
			    plot_gsn, catfiles
			end else begin
			    imenu = wmenu_sel(catfiles, /one)
			    if (imenu ne -1) then plot_gsn, catfiles(imenu)
			end
		  end

	    ;--------------------- Plotting options
	    'MA': input, 'Enter mailing address (ie: morrison@sxt2.space.lockheed.com)', mail_address, 'NONE'
	    'ME': qmail = 1
	    'MD': qmail = 0

	    ;--------------------- Plotting options
	    'X': qdone = 1
	    else: begin
			tbeep, 1
			print, 'Unrecognized command
		  end
	endcase
end
;
end


